@@ -1,5 +1,5 @@
 /*
- * Copyright (C) 2020-2021 Intel Corporation
+ * Copyright (C) 2020-2025 Intel Corporation
  *
  * SPDX-License-Identifier: MIT
  *
@@ -11,6 +11,7 @@
 #include "layers/zel_tracing_api.h"
 #include "layers/zel_tracing_register_cb.h"
 #include "ze_tracing_cb_structs.h"
+#include "zer_tracing_cb_structs.h"
 
 struct _zel_tracer_handle_t {};
 
@@ -25,7 +26,8 @@ struct APITracer : _zel_tracer_handle_t {
     virtual ze_result_t destroyTracer(zel_tracer_handle_t phTracer) = 0;
     virtual ze_result_t setPrologues(zel_core_callbacks_t *pCoreCbs) = 0;
     virtual ze_result_t setEpilogues(zel_core_callbacks_t *pCoreCbs) = 0;
-    virtual zel_all_core_callbacks_t& getProEpilogues(zel_tracer_reg_t callback_type, ze_result_t& result) = 0;
+    virtual zel_ze_all_callbacks_t& getZeProEpilogues(zel_tracer_reg_t callback_type, ze_result_t& result) = 0;
+    virtual zel_zer_all_callbacks_t& getZerProEpilogues(zel_tracer_reg_t callback_type, ze_result_t& result) = 0;
     virtual ze_result_t resetAllCallbacks() = 0;
     virtual ze_result_t enableTracer(ze_bool_t enable) = 0;
 };
