@@ -1,8 +1,8 @@
 /*
  * ***THIS FILE IS GENERATED. ***
- * See valddi.cpp.mako for modifications
+ * See param.cpp.mako for modifications
  *
- * Copyright (C) 2019-2023 Intel Corporation
+ * Copyright (C) 2019-2025 Intel Corporation
  *
  * SPDX-License-Identifier: MIT
  *
@@ -167,7 +167,7 @@ namespace validation_layer
         if( nullptr == buffer )
             return ZE_RESULT_ERROR_INVALID_NULL_POINTER;
 
-        if( ZET_DEBUG_MEMORY_SPACE_TYPE_ELF < desc->type )
+        if( ZET_DEBUG_MEMORY_SPACE_TYPE_BARRIER < desc->type )
             return ZE_RESULT_ERROR_INVALID_ENUMERATION;
 
         return ParameterValidation::validateExtensions(desc);
@@ -192,7 +192,7 @@ namespace validation_layer
         if( nullptr == buffer )
             return ZE_RESULT_ERROR_INVALID_NULL_POINTER;
 
-        if( ZET_DEBUG_MEMORY_SPACE_TYPE_ELF < desc->type )
+        if( ZET_DEBUG_MEMORY_SPACE_TYPE_BARRIER < desc->type )
             return ZE_RESULT_ERROR_INVALID_ENUMERATION;
 
         return ParameterValidation::validateExtensions(desc);
@@ -259,8 +259,8 @@ namespace validation_layer
                                                         ///< than the `count` member of ::zet_debug_regset_properties_t for the
                                                         ///< type
         uint32_t count,                                 ///< [in] the number of registers to read; start+count must be less than or
-                                                        ///< equal to the `count` member of ::zet_debug_register_group_properties_t
-                                                        ///< for the type
+                                                        ///< equal to the `count` member of ::zet_debug_regset_properties_t for the
+                                                        ///< type
         void* pRegisterValues                           ///< [in,out][optional][range(0, count)] buffer of register values
         )
     {
@@ -280,8 +280,8 @@ namespace validation_layer
                                                         ///< than the `count` member of ::zet_debug_regset_properties_t for the
                                                         ///< type
         uint32_t count,                                 ///< [in] the number of registers to write; start+count must be less than
-                                                        ///< or equal to the `count` member of
-                                                        ///< ::zet_debug_register_group_properties_t for the type
+                                                        ///< or equal to the `count` member of ::zet_debug_regset_properties_t for
+                                                        ///< the type
         void* pRegisterValues                           ///< [in,out][optional][range(0, count)] buffer of register values
         )
     {
@@ -1014,6 +1014,49 @@ namespace validation_layer
     }
 
 
+    ze_result_t
+    ZETParameterValidation::zetCommandListAppendMarkerExpPrologue(
+        zet_command_list_handle_t hCommandList,         ///< [in] handle to the command list
+        zet_metric_group_handle_t hMetricGroup,         ///< [in] handle to the marker metric group.
+                                                        ///< ::zet_metric_group_type_exp_flags_t could be used to check whether
+                                                        ///< marker is supoported by the metric group.
+        uint32_t value                                  ///< [in] marker value
+        )
+    {
+        if( nullptr == hCommandList )
+            return ZE_RESULT_ERROR_INVALID_NULL_HANDLE;
+
+        if( nullptr == hMetricGroup )
+            return ZE_RESULT_ERROR_INVALID_NULL_HANDLE;
+
+        return ZE_RESULT_SUCCESS;
+    }
+
+
+    ze_result_t
+    ZETParameterValidation::zetDeviceEnableMetricsExpPrologue(
+        zet_device_handle_t hDevice                     ///< [in] handle of the device where metrics collection has to be enabled.
+        )
+    {
+        if( nullptr == hDevice )
+            return ZE_RESULT_ERROR_INVALID_NULL_HANDLE;
+
+        return ZE_RESULT_SUCCESS;
+    }
+
+
+    ze_result_t
+    ZETParameterValidation::zetDeviceDisableMetricsExpPrologue(
+        zet_device_handle_t hDevice                     ///< [in] handle of the device where metrics collection has to be disabled
+        )
+    {
+        if( nullptr == hDevice )
+            return ZE_RESULT_ERROR_INVALID_NULL_HANDLE;
+
+        return ZE_RESULT_SUCCESS;
+    }
+
+
     ze_result_t
     ZETParameterValidation::zetMetricGroupCalculateMultipleMetricValuesExpPrologue(
         zet_metric_group_handle_t hMetricGroup,         ///< [in] handle of the metric group
